@@ -3,8 +3,6 @@
 ###################
 # Scripts made by Eric #
 
-from ..Core.init import Init
-
 class colors:
   HEADER = '\033[95m'
   OKBLUE = '\033[94m'
@@ -14,6 +12,4 @@ class colors:
   FAIL = '\033[91m'
   ENDC = '\033[0m'
   BOLD = '\033[1m'
-  UNDERLINE = '\033[4m'
-
-Init()
\ No newline at end of file
+  UNDERLINE = '\033[4m'
\ No newline at end of file
